// Licensed to Apache Software Foundation (ASF) under one or more contributor
// license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright
// ownership. Apache Software Foundation (ASF) licenses this file to you under
// the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package cmd

import (
	"context"

	"github.com/spf13/cobra"

	"github.com/apache/skywalking-rover/pkg/boot"
)

func newStartCmd() *cobra.Command {
	configPath := ""
	cmd := &cobra.Command{
		Use:   "start",
		Short: "start the rover",
		RunE: func(cmd *cobra.Command, args []string) error {
			ctx := context.Background()

			// run modules
			return boot.RunModules(ctx, configPath, nil)
		},
	}

	cmd.Flags().StringVarP(&configPath, "config", "c", "configs/rover_configs.yaml", "the rover config file path")
	return cmd
}
